pub struct Cursor<'a, T, A = Global>
where T: 'a, A: Allocator,
{ /* private fields */ }
๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)
Available on crate feature wayland and Linux only.
A cursor over a LinkedList.

A Cursor is like an iterator, except that it can freely seek back-and-forth.

Cursors always rest between two elements in the list, and index in a logically circular way. To accommodate this, there is a โ€œghostโ€ non-element that yields None between the head and tail of the list.

When created, cursors start at the front of the list, or the โ€œghostโ€ non-element if the list is empty.

Implementations

Source

impl<'a, T, A> Cursor<'a, T, A>
where A: Allocator,

pub fn index(&self) -> Option<usize>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Returns the cursor position index within the LinkedList.

This returns None if the cursor is currently pointing to the โ€œghostโ€ non-element.

pub fn move_next(&mut self)

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Moves the cursor to the next element of the LinkedList.

If the cursor is pointing to the โ€œghostโ€ non-element then this will move it to the first element of the LinkedList. If it is pointing to the last element of the LinkedList then this will move it to the โ€œghostโ€ non-element.

pub fn move_prev(&mut self)

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Moves the cursor to the previous element of the LinkedList.

If the cursor is pointing to the โ€œghostโ€ non-element then this will move it to the last element of the LinkedList. If it is pointing to the first element of the LinkedList then this will move it to the โ€œghostโ€ non-element.

pub fn current(&self) -> Option<&'a T>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Returns a reference to the element that the cursor is currently pointing to.

This returns None if the cursor is currently pointing to the โ€œghostโ€ non-element.

pub fn peek_next(&self) -> Option<&'a T>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Returns a reference to the next element.

If the cursor is pointing to the โ€œghostโ€ non-element then this returns the first element of the LinkedList. If it is pointing to the last element of the LinkedList then this returns None.

pub fn peek_prev(&self) -> Option<&'a T>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Returns a reference to the previous element.

If the cursor is pointing to the โ€œghostโ€ non-element then this returns the last element of the LinkedList. If it is pointing to the first element of the LinkedList then this returns None.

pub fn front(&self) -> Option<&'a T>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Provides a reference to the front element of the cursorโ€™s parent list, or None if the list is empty.

pub fn back(&self) -> Option<&'a T>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Provides a reference to the back element of the cursorโ€™s parent list, or None if the list is empty.

pub fn as_list(&self) -> &'a LinkedList<T, A>

๐Ÿ”ฌThis is a nightly-only experimental API. (linked_list_cursors)

Provides a reference to the cursorโ€™s parent list.