pub struct Cursor<'a, T, A = Global>where
T: 'a,
A: Allocator,{ /* private fields */ }linked_list_cursors)wayland and Linux only.Expand description
A cursor over a LinkedList.
A Cursor is like an iterator, except that it can freely seek back-and-forth.
Cursors always rest between two elements in the list, and index in a logically circular way.
To accommodate this, there is a โghostโ non-element that yields None between the head and
tail of the list.
When created, cursors start at the front of the list, or the โghostโ non-element if the list is empty.
Implementations
Sourceimpl<'a, T, A> Cursor<'a, T, A>where
A: Allocator,
impl<'a, T, A> Cursor<'a, T, A>where
A: Allocator,
Sourcepub fn index(&self) -> Option<usize>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn index(&self) -> Option<usize>
linked_list_cursors)Returns the cursor position index within the LinkedList.
This returns None if the cursor is currently pointing to the
โghostโ non-element.
Sourcepub fn move_next(&mut self)
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn move_next(&mut self)
linked_list_cursors)Moves the cursor to the next element of the LinkedList.
If the cursor is pointing to the โghostโ non-element then this will move it to
the first element of the LinkedList. If it is pointing to the last
element of the LinkedList then this will move it to the โghostโ non-element.
Sourcepub fn move_prev(&mut self)
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn move_prev(&mut self)
linked_list_cursors)Moves the cursor to the previous element of the LinkedList.
If the cursor is pointing to the โghostโ non-element then this will move it to
the last element of the LinkedList. If it is pointing to the first
element of the LinkedList then this will move it to the โghostโ non-element.
Sourcepub fn current(&self) -> Option<&'a T>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn current(&self) -> Option<&'a T>
linked_list_cursors)Returns a reference to the element that the cursor is currently pointing to.
This returns None if the cursor is currently pointing to the
โghostโ non-element.
Sourcepub fn peek_next(&self) -> Option<&'a T>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn peek_next(&self) -> Option<&'a T>
linked_list_cursors)Returns a reference to the next element.
If the cursor is pointing to the โghostโ non-element then this returns
the first element of the LinkedList. If it is pointing to the last
element of the LinkedList then this returns None.
Sourcepub fn peek_prev(&self) -> Option<&'a T>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn peek_prev(&self) -> Option<&'a T>
linked_list_cursors)Returns a reference to the previous element.
If the cursor is pointing to the โghostโ non-element then this returns
the last element of the LinkedList. If it is pointing to the first
element of the LinkedList then this returns None.
Sourcepub fn front(&self) -> Option<&'a T>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn front(&self) -> Option<&'a T>
linked_list_cursors)Provides a reference to the front element of the cursorโs parent list, or None if the list is empty.
Sourcepub fn back(&self) -> Option<&'a T>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn back(&self) -> Option<&'a T>
linked_list_cursors)Provides a reference to the back element of the cursorโs parent list, or None if the list is empty.
Sourcepub fn as_list(&self) -> &'a LinkedList<T, A>
๐ฌThis is a nightly-only experimental API. (linked_list_cursors)
pub fn as_list(&self) -> &'a LinkedList<T, A>
linked_list_cursors)Provides a reference to the cursorโs parent list.